Due to an issue with `pgaudit` that prevents us from using `conn.stream()`/`conn.cursor()`, we have to migrate to a newer Postgres version.
Currently, the only Postgres version that has the fix is Postgres 13 so we migrated to it in VDP. However, in commercial we can't use
Postgres 13 because RDS Proxy supports only versions 11 and less. For this reason, we have to support 2 versions of RDS - 11 and 13.
The problem is, in Postgres 12 they changed the way how default composite FKs are named. For example, in Postgres 11, a FK in table `A`,
on columns `x` and `y` would be called `A_x_fkey` but in Postgres 13 - it would be called `A_x_y_fkey`. Due to this change, some of our
migrations were not compatible with Postgres 13, and we had to fix them. **Now, until we start using a single Postgres version for VDP and
commercial, we must give all FKs explicit names. Also, there might be other changes that we are so far unaware of, so it would be a
good idea to give every new Postgres struct (be it an index, sequence, view, or whatever) and explicit name.**

When can we return to using a single Postgres version?
- if RDS Proxy starts supporting Postgres 13, we can migrate to it in commercial
  - [Check here](https://docs.aws.amazon.com/AmazonRDS/latest/AuroraUserGuide/rds-proxy.html) 
    for RDS Proxy limitations in terms of supported versions
- if the newly released version of Postgres 11.13 contains the fix for `pgaudt` we can migrate to 11.13 in both 
  commercial and VDP
  - 11.13 is already released by Postgres, but I guess AWS will release it not earlier than November.
  - [Check here](https://docs.aws.amazon.com/AmazonRDS/latest/UserGuide/CHAP_PostgreSQL.html#PostgreSQL.Concepts.General.version11) for new releases
  - [Check here](https://docs.aws.amazon.com/AmazonRDS/latest/UserGuide/CHAP_PostgreSQL.html#PostgreSQL.Concepts.General.FeatureSupport.Extensions.11x)
    to verify that 11.13 actually supports `pgaudit` version >= 1.3.2 in which the issue is fixed
    
When we start to support a single version, we can remove `test_sql_schema.py` that verifies Postgres 11 and 13 produce the same schema
and we can also remove the READ_THE_README step from the `.gitlab-ci.yaml` file.

[Link to ticket for more details](https://jira.carbonblack.local/browse/LC-1247)