import datetime
from typing import NamedTuple, List, Optional

from feed_manager.api.models import IOC_V2, FeedInfo, Report
from pscr_common.api.models import with_swagger_definition, with_from_dict


@with_swagger_definition
@with_from_dict
class ExtendedReport(NamedTuple):
    id: str
    timestamp: datetime.datetime
    title: str
    description: str
    severity: int
    iocs: List[IOC_V2]
    source: str
    access: str
    source_label: Optional[str] = None
    link: Optional[str] = None
    tags: Optional[List[str]] = None
    feed_id: Optional[str] = None
    feed_name: Optional[str] = None
    feed_provider_url: Optional[str] = None
    feed_summary: Optional[str] = None
    feed_category: Optional[str] = None
    feed_delegates: Optional[List[str]] = None

    @classmethod
    def from_basic(
        cls,
        report: Report,
        source: str,
        access: str,
        feedinfo: FeedInfo = None,
        delegates: List[str] = None,
    ):
        return ExtendedReport(
            id=report.id,
            timestamp=report.timestamp,
            title=report.title,
            description=report.description,
            severity=report.severity,
            iocs=report.iocs_v2,
            source=source,
            access=access,
            source_label=feedinfo.source_label if feedinfo else None,
            link=report.link,
            tags=report.tags,
            feed_id=feedinfo.id if feedinfo else None,
            feed_name=feedinfo.name if feedinfo else None,
            feed_provider_url=feedinfo.provider_url if feedinfo else None,
            feed_summary=feedinfo.summary if feedinfo else None,
            feed_category=feedinfo.category if feedinfo else None,
            feed_delegates=delegates,
        )
