import json
import logging

import botocore
from pscr_common.aws import get_boto3_client

from feed_manager.utils.tasks.background_task import BackgroundTask
from feed_manager.utils.config import Config
from feed_manager.utils.mem_cache import MemCache

_logger = logging.getLogger(__name__)


class UpdateOrgFeaturesCacheTask(BackgroundTask):
    def __init__(self, config: Config):
        super(UpdateOrgFeaturesCacheTask, self).__init__(
            "update_org_features_cache_task",
            loop_sec=config.getint("features", "cache_update_minutes", fallback=10)
            * 60,
            sleep_first=False,
            execute_once=False,
        )
        self.s3_bucket = config.get("aws", "admin_bucket")
        self.cache = MemCache()

    async def execute(self, app) -> None:
        try:
            s3_client = get_boto3_client("s3")
            org_features = (
                s3_client.get_object(
                    Bucket=self.s3_bucket, Key="org_features/features.json"
                )["Body"]
                .read()
                .decode("utf-8")
            )
            self.cache.set("org_features", json.loads(org_features))
            _logger.info("Added org features to memory cache")
        except botocore.exceptions.ClientError as error:
            _logger.error(
                f"Error downloading org features due to {error.response['Error']['Code']}"
            )
